pub struct FrameControl(pub u8);Expand description
See Section 2.4.1.1
Tuple Fields
0: u8Implementations
Sourceimpl FrameControl
impl FrameControl
Sourcepub fn frame_type(self) -> FrameType
pub fn frame_type(self) -> FrameType
See Section 2.4.1.1.1
Returns true if command is global
Sourcepub fn is_manufacturer_specific(self) -> bool
pub fn is_manufacturer_specific(self) -> bool
The Manufacturer Specific field specifies whether this command refers to a manufacturer specific extension.
If this value is set to 1, the manufacturer code field SHALL be present in
the ZCLframe.
See Section 2.4.1.1.2
Sourcepub fn direction(self) -> bool
pub fn direction(self) -> bool
The direction specifies the client/server direction for this command. If set to 1, the command is being sent from the server side of a cluster to the client side of a cluster.
See Section 2.4.1.1.3
Sourcepub fn disable_default_response(self) -> bool
pub fn disable_default_response(self) -> bool
See Section 2.4.1.1.4